Propellants — RocketCEA 1.0.5 documentation

# Propellants

The table below displays the propellants built in to RocketCEA. Click any of the names to see the card deck submitted to CEA for that propellant.

If your propellant is not included, or if you disagree with the definitions, new propellants can be added, and existing propellants can be modified.

Any use of RocketCEA begins with an import statement and an instance of CEA_Obj:

    from rocketcea.cea_obj import CEA_Obj
    C = CEA_Obj( oxName='N2O4', fuelName='MMH')

Bipropellant runs use oxName and fuelName to define propellants. For Monopropellants and Solid Propellants, the instance of CEA_Obj uses propName:

    from rocketcea.cea_obj import CEA_Obj
    C = CEA_Obj( propName='HYD40')

Click Propellant Name to View Definition

Oxidizers
90_H2O2 | 98_H2O2 | AIR | AIRSIMP | CLF3 | CLF5 | F2 | GO2
GOX | H2O | H2O2 | HAN315 | HNO3 | IRFNA | LO2 | LOX
MON15 | MON25 | MON3 | N2F4 | N2H4 | N2O | N2O3 | N2O4
N2O_nbp | O2 | OF2 | Peroxide90 | Peroxide98 |  |  |
Fuels
A50 | Acetylene | AL | AP | B2H6 | C2H2 | C2H5OH | C2H6
C2H6_167 | C3H8 | CFx | CH3OH | CH4 | CINCH | DMAZ | ECP_dimer
Ethanol | ETHANOL | Gasoline | GCH4 | GH2 | GH2_160 | H2 | H2O
HTPB | Isopropanol | JetA | JP10 | JP4 | JPX | Kerosene | Kerosene90_H2O10
LH2 | M20 | M20_NH3 | Methanol | METHANOL | MHF3 | MMH | N2H4
NH3 | NITROMETHANE | Propane | Propylene | propylene | RP1 | RP_1 | UDMH
Monoprop & Solid
AMT_2091 | AP10_RDX25_HTPB | ARC311 | ARC448 | ARC452 | ARC457 | HAN269 | HAN315
HPB24 | HYD40 |  |  |  |  |  |

## Special Blends

There are a number of special blends that can be created when making an instance of CEA_Obj.

### Hydrazine Monopropellant

The performance of Hydrazine Monopropellant engines is driven by the amount of ammonia dissociation that the catalyst bed delivers. Any amount of ammonia dissociation can be run by calling out the propName as “HYD” + weight percent dissociation.

Note that the CEA FORTRAN code has been modified to include “Undissociated Ammonia (UA)” as an exhaust product. The CEA input also includes an “omit NH3” statement to prevent normal NH3 calculations.

The examples below call out 30, 40 and 50 percent ammonia dissociation.:

    C = CEA_Obj( propName='HYD30')
    C = CEA_Obj( propName='HYD40')
    C = CEA_Obj( propName='HYD50')

### MMH + N2H4

Mixtures of MMH and N2H4 are often used to suppress the freezing point of N2H4. M20 is a common mixture (20% MMH + 80% N2H4 by weight). The examples below call out 10, 20 and 30 percent MMH:

    C = CEA_Obj( oxName='N2O4', fuelName='M10')
    C = CEA_Obj( oxName='N2O4', fuelName='M20')
    C = CEA_Obj( oxName='N2O4', fuelName='M30')

### Mixed Oxides of Nitrogen

Mixtures of N2O4 and NO are often used to suppress the freezing point of N2O4. MON25 is a common mixture (25% NO + 75% N2O4 by weight).

When NO is added to N2O4, there are two main equilibrium reactions:

    N2O4     <==> 2 NO2
    NO + NO2 <==> N2O3

For this reason, the input cards for MON oxidizers include N2O4 and N2O3. The weight percentages are calculated based on the equilibrium equations above.

The examples below call out MON oxidizers with 15, 20 and 25 percent NO:

    C = CEA_Obj( oxName='MON15', fuelName='MMH')
    C = CEA_Obj( oxName='MON20', fuelName='MMH')
    C = CEA_Obj( oxName='MON25', fuelName='MMH')

### Peroxide + Water

Peroxide is often blended with water in order to enhance its stability and improve its safety. While the debate about an appropriate blend of Peroxide rages on, analyzing it with RocketCEA simply requires calling it out as “Peroxide” + weight percent Peroxide. The examples below call out 90, 95 and 98 percent Peroxide:

    C = CEA_Obj( propName='Peroxide90')
    C = CEA_Obj( propName='Peroxide95')
    C = CEA_Obj( propName='Peroxide98')
    C = CEA_Obj(   oxName='Peroxide98', fuelName="MMH")

### FLOX

FLOX is a mixture of Fluorine and Oxygen. Call out the mixture as “FLOX” + weight percent of Fluorine. The examples below call out 60, 70 and 80 percent Fluorine:

    C = CEA_Obj(   oxName='FLOX60', fuelName="LH2")
    C = CEA_Obj(   oxName='FLOX70', fuelName="LH2")
    C = CEA_Obj(   oxName='FLOX80', fuelName="LH2")

## Oxidizers

### 90_H2O2

    oxid H2O2(L) H 2 O 2  wt%=90.00
    h,cal=-44880.0     t(k)=298.15  rho.g/cc=1.407
    oxid = WATER H 2.0 O 1.0 wt%= 10.0
    h.cal=-68317. t(k)=298.15 rho.g/cc=1.0

### 98_H2O2

    oxid H2O2(L) H 2 O 2  wt%=98.00
    h,cal=-44880.0     t(k)=298.15  rho.g/cc=1.407
    oxid = WATER H 2.0 O 1.0 wt%= 2.0
    h.cal=-68317. t(k)=298.15 rho.g/cc=1.0

### AIR

    oxid Air    wt%=100.00
    h,cal=-28.2     t(k)=298.15

### AIRSIMP

    oxid AIRSIMP  N 1.5622 O .4192 Ar .0093
    h,cal=0.     t(k)=298.15

### CLF3

    oxid CLF3(L)   CL 1 F 3   wt%=100.00
    h,cal=-45680.0     t(k)=298.15

### CLF5

    oxid CLF5(L)   CL 1 F 5   wt%=100.00
    h,cal=-60500.0     t(k)=298.15

### F2

    oxid F2(L)  F 2
    h,cal=-3098.      t(k)=82.02       wt%=100.

### GO2

    oxid O2(G)  O 2
    h,cal=0.      t(k)=298.15       wt%=100.

### GOX

    oxid O2(G)  O 2
    h,cal=0.      t(k)=298.15       wt%=100.

### H2O

    oxid water H 2.0 O 1.0  wt%=100.0
    h,cal=-68308.  t(k)=298.15 rho,g/cc = 0.9998

### H2O2

    oxid H2O2(L) H 2 O 2  wt%=100.00
    h,cal=-44880.0     t(k)=298.15  rho.g/cc=1.407

### HAN315

    oxid = HAN C 0.064 H 4.296 N 2.062 O 4.1 P 0.008 wt%= 44.5
    h.cal=-93980. t(k)=298.15 rho.g/cc=1.685
    oxid = HEHN C 2.0 H 9.0 N 3.0 O 4.0 wt%= 44.5
    h.cal=-108000. t(k)=298.15 rho.g/cc=1.428
    oxid = WATER H 2.0 O 1.0 wt%= 11.0
    h.cal=-68000. t(k)=298.15 rho.g/cc=1.0

### HNO3

    oxid HNO3(L) H 1 N 1 O 3   wt%=100.00
    h,cal=-42460.0     t(k)=298.15  rho.g/cc=1.5027

### IRFNA

    oxid IRFNA  H 1.57216 N 1.62945 O 4.69505 F 0.02499   wt%=100.00
    h,cal=-64860.0     t(k)=298.15  rho.g/cc=1.48

### LO2

    oxid O2(L)  O 2
    h,cal=-3102.      t(k)=90.18       wt%=100.

### LOX

    oxid O2(L)  O 2
    h,cal=-3102.      t(k)=90.18       wt%=100.

### MON15

    oxid N2O4(L)   N 2 O 4   wt%=62.01
    h,cal=-4676.0     t(k)=298.15
    oxid N2O3   N 2 O 3   wt%=37.99
    h,cal=12020.7     t(k)=298.15

### MON25

    oxid N2O4(L)   N 2 O 4   wt%=36.67
    h,cal=-4676.0     t(k)=298.15
    oxid N2O3   N 2 O 3   wt%=63.33
    h,cal=12020.7     t(k)=298.15

### MON3

    oxid N2O4(L)   N 2 O 4   wt%=100.00
    h,cal=-4676.0     t(k)=298.15

### N2F4

    oxid N2F4(L)  N 2 F 4
    h,cal=-5200.0      t(k)=199.0       wt%=100.

### N2H4

    oxid N2H4(L)  N 2 H 4    wt%=100.
    h,cal=12100.0     t(k)=298.15   rho=1.0036

### N2O

    oxid NitrousOxide  N 2.0 O 1.0  wt%=100.00
    h,cal= 19467.0 t(k)=298.15

### N2O3

    oxid N2O3(L)   N 2 O 3   wt%=100.00
    h,cal=12020.7     t(k)=298.15

### N2O4

    oxid N2O4(L)   N 2 O 4   wt%=100.00
    h,cal=-4676.0     t(k)=298.15

### N2O_nbp

    oxid NitrousOxide  N 2.0 O 1.0  wt%=100.00
    h,cal= 14583.0 t(k)=184.4

### O2

    oxid O2(L)  O 2
    h,cal=-3102.      t(k)=90.18       wt%=100.

### OF2

    oxid OF2(L)  O 1 F 2
    h,cal=2524.      t(k)=167.0       wt%=100.

### Peroxide90

    oxid H2O2(L) H 2 O 2  wt%=90.00
    h,cal=-44880.0     t(k)=298.15  rho.g/cc=1.407
    oxid = WATER H 2.0 O 1.0 wt%= 10.0
    h.cal=-68317. t(k)=298.15 rho.g/cc=1.0

### Peroxide98

    oxid H2O2(L) H 2 O 2  wt%=98.00
    h,cal=-44880.0     t(k)=298.15  rho.g/cc=1.407
    oxid = WATER H 2.0 O 1.0 wt%= 2.0
    h.cal=-68317. t(k)=298.15 rho.g/cc=1.0

## Fuels

### A50

    fuel C2H8N2(L),UDMH wt% 50.   t(k) 298.15
    h,cal=11900.0     t(k)=298.15   rho=.783
    fuel N2H4(L)  N 2 H 4    wt%=50.
    h,cal=12100.0     t(k)=298.15   rho=1.0036

### Acetylene

    fuel Acetylene  C 2 H 2   wt%=100.
    h,cal=54324.     t(k)=198.3   rho=0.9

### AL

    fuel  Aluminum  t(k)=298.15 AL 1                               wt%=100.00
    h,cal=0.0     t(k)=298.15

### AP

    fuel NH4CLO4(I)       wt%=100.00

### B2H6

    fuel B2H6(L)   B 2 H 6
    h,cal=4970.0      t(k)=180.0       wt%=100.

### C2H2

    fuel Acetylene  C 2 H 2   wt%=100.
    h,cal=54324.     t(k)=198.3   rho=0.9

### C2H5OH

    fuel C2H5OH(L)   C 2 H 6 O 1
    h,cal=-66370.0      t(k)=298.15       wt%=100.

### C2H6

    fuel C2H6(L) C 2 H 6     wt%=100.
    h,cal=-24797.0     t(k)=184.56   rho=0.5808

### C2H6_167

    fuel C2H6(L) C 2 H 6     wt%=100.
    h,cal=-25296.0     t(k)=167.0   rho=0.5808

### C3H8

    fuel C3H8(L) C 3 H 8     wt%=100.
    h,cal=-30372.     t(k)=231.08   rho=0.5808

### CFx

    fuel CFx    C 1.0 F 1.0   wt%=100.00
    h,cal=57863.0     t(k)=298.15   rho=1.8200

### CH3OH

    fuel CH3OH(L)   C 1 H 4 O 1
    h,cal=-57040.0      t(k)=298.15       wt%=100.

### CH4

    fuel CH4(L) C 1 H 4     wt%=100.
    h,cal=-21390.     t(k)=111.66   rho=0.4239

### CINCH

    fuel CINCH(L)     C 4.     H 10.    N 4.
    h,cal=66550.      t(k)=298.15             wt%=100.

### DMAZ

    fuel dmaz C 4.0 H 10.0 N 4.0 wt%= 100.00
    h,cal=66548. t(k)=298.15 rho,g/cc = 0.93

### ECP_dimer

    fuel ECP-dimer(L) C 10.    H 10.
    h,cal=123600.     t(k)=298.15                     wt%=100.

### Ethanol

    fuel C2H5OH(L)   C 2 H 6 O 1
    h,cal=-66370.0      t(k)=298.15       wt%=100.

### ETHANOL

    fuel C2H5OH(L)   C 2 H 6 O 1
    h,cal=-66370.0      t(k)=298.15       wt%=100.

### Gasoline

    fuel Gasoline  C 8 H 18
    h,cal=-49809.     t(k)=298.15   rho=0.7025

### GCH4

    fuel CH4(G) C 1 H 4
    h,cal=-17895.0      t(k)=298.15       wt%=100.

### GH2

    fuel H2(G)  H 2
    h,cal=0.      t(k)=298.15       wt%=100.

### GH2_160

    fuel H2(G)  H 2
    h,cal=-940.      t(k)=160.0       wt%=100.

### H2

    fuel H2(L)  H 2
    h,cal=-2154.0      t(k)=20.27       wt%=100.

### H2O

    fuel water H 2.0 O 1.0  wt%=100.0
    h,cal=-68308.  t(k)=298.15 rho,g/cc = 0.9998

### HTPB

    fuel R-45(HTPB FROM_RPL_DATA) C 7.3165 H 10.3360 O 0.1063    wt%=100.00
    h,cal= 1200.0 t(k)=298.15 rho=0.9220

### Isopropanol

    fuel C3H8O-2propanol C 3 H 8 O 1    wt%=100.
    h,cal=-65133.     t(k)=298.15   rho=0.786

### JetA

    fuel Jet-A(L)  C  12.0 H  23.0
    h,cal=-72466.6     t(k)=298.15   rho=0.815

### JP10

    fuel JP10  C 10 H 16  wt%=100.00
    h,cal=-29350.     t(k)=298.15   rho=0.9318

### JP4

    fuel Kerosene  C 1 H 1.9532  wt%=50.00
    h,cal=-5769.     t(k)=298.15   rho=0.8
    fuel Gasoline  C 8 H 18  wt%=50.00
    h,cal=-49809.     t(k)=298.15   rho=0.7025

### JPX

    fuel C2H8N2(L),UDMH wt%=60.   t(k) 298.15
    h,cal=11900.0     t(k)=298.15   rho=.783
    fuel Kerosene  C 1 H 1.9532  wt%=30.00
    h,cal=-5769.     t(k)=298.15   rho=0.8
    fuel Gasoline  C 8 H 18  wt%=30.00
    h,cal=-49809.     t(k)=298.15   rho=0.7025

### Kerosene

    fuel Kerosene  C 1 H 1.9532
    h,cal=-5769.     t(k)=298.15   rho=0.8

### Kerosene90_H2O10

    fuel Kerosene  C 1 H 1.9532  wt%=90.00
    h,cal=-5769.     t(k)=298.15   rho=0.8
    fuel = WATER H 2.0 O 1.0  wt%= 10.0
    h.cal=-68317. t(k)=298.15 rho.g/cc=1.0

### LH2

    fuel H2(L)  H 2
    h,cal=-2154.0      t(k)=20.27       wt%=100.

### M20

    fuel CH6N2(L)  C 1 H 6 N 2  wt%=20.0
    h,cal=12900.0     t(k)=298.15   rho=.874
    fuel N2H4(L)  N 2 H 4    wt%=80.0
    h,cal=12100.0     t(k)=298.15   rho=1.0036

### M20_NH3

    fuel CH6N2(L)  C 1 H 6 N 2  wt%=17.9
    h,cal=12900.0     t(k)=298.15   rho=.874
    fuel N2H4(L)  N 2 H 4    wt%=71.6
    h,cal=12100.0     t(k)=298.15   rho=1.0036
    fuel NH3(L)   N 1 H 3      wt%=10.5
    h,cal=-17090.     t(k)=298.15   rho=0.676

### Methanol

    fuel CH3OH(L)   C 1 H 4 O 1
    h,cal=-57040.0      t(k)=298.15       wt%=100.

### METHANOL

    fuel CH3OH(L)   C 1 H 4 O 1
    h,cal=-57040.0      t(k)=298.15       wt%=100.

### MHF3

    fuel CH6N2(L)  C 1 H 6 N 2  wt%=86.0
    h,cal=12900.0     t(k)=298.15   rho=.874
    fuel N2H4(L)  N 2 H 4    wt%=14.0
    h,cal=12100.0     t(k)=298.15   rho=1.0036

### MMH

    fuel CH6N2(L)  C 1     H 6     N 2     wt%=100.00
    h,cal=12900.0     t(k)=298.15   rho=.874

### N2H4

    fuel N2H4(L)  N 2 H 4    wt%=100.
    h,cal=12100.0     t(k)=298.15   rho=1.0036

### NH3

    fuel NH3(L)   N 1 H 3      wt%=100.
    h,cal=-17090.     t(k)=298.15   rho=0.676

### NITROMETHANE

    fuel nitroMethane C 1. H 3. N 1. O 2. wt%= 100.00
    h,cal=-27030. t(k)=298.15  rho,g/cc =1.1371

### Propane

    fuel C3H8(L) C 3 H 8     wt%=100.
    h,cal=-30372.     t(k)=231.08   rho=0.5808

### Propylene

    fuel C3H6,propylene C 3 H 6    wt%=100.
    h,cal=4776.92     t(k)=298.15   rho=0.0018

### propylene

    fuel C3H6,propylene C 3 H 6    wt%=100.
    h,cal=4776.92     t(k)=298.15   rho=0.0018

### RP1

    fuel RP-1  C 1 H 1.9423
    h,cal=-5430.     t(k)=298.15   rho=0.773

### RP_1

    fuel RP-1  C 1 H 1.9423
    h,cal=-5430.     t(k)=298.15   rho=0.773

### UDMH

    fuel C2H8N2(L),UDMH wt% 50.   t(k) 298.15
    h,cal=11900.0     t(k)=298.15   rho=.783

## Monoprop & Solid

### AMT_2091

    name NH4NO3         H  4.9968 O  3.7476 N  2.4984                   wt%=75.00
    h,cal=-109019.9966   t(k)=298.15   rho=1.7250
    name (NH4)2CR2O7   H  3.1733 O  2.7766  N  0.7933  CR 0.7933        wt%=2.00
    h,cal=-168780.   t(k)=298.15   rho=2.1500
    name A-20_GENPOL  C  4.5500  H  7.1000  O  2.3900                   wt%=7.24
    h,cal=-111000.   t(k)=298.15   rho=1.0380
    name METHYL_ACRYLATE   C  4.6464  H  6.9696  O  2.3232              wt%=11.08
    h,cal=-111300.   t(k)=298.15   rho=1.2000
    name POLYSTYRENE  C  7.6817  H  7.6817                              wt%=3.957
    h,cal=8000.   t(k)=298.15   rho=1.0600
    name MAKP   C  5.3768  H 10.7535  O  1.5362  wt%=0.40
    h,cal=-134060.   t(k)=298.15   rho=0.8500
    name CALCIUM_PHOSPHATE  P  0.6447  CA 0.9671 O  2.5790              wt%=0.50
    h,cal=-300500.   t(k)=298.15   rho=3.1400
    name TIN_OCTOATE  C  3.9497 H  7.4057 O  0.9874 PB 0.0948 CU 0.1521 wt%=0.003
    h,cal=-76120.   t(k)=298.15   rho=1.0000
    name LECITHIN  C  5.5611 H 11.1223 O  1.2692 N  0.1208              wt%=0.18
    h,cal=-63010.   t(k)=298.15   rho=1.0220

### AP10_RDX25_HTPB

    name NH4CLO4(I)       wt%=10.0
    name RDX    C 1.3506 H 2.7011 O 2.7011 N 2.7011  wt%=25.00
    h,cal=6610.     t(k)=298.15   rho=1.8200
    name R-45(HTPB FROM_RPL_DATA) C 7.3165 H 10.3360 O 0.1063    wt%=65.00
    h,cal= 1200.0 t(k)=298.15 rho=0.9220

### ARC311

    name ARC311  H 3.919935 C 2.237043 N 2.300870 O 2.309573  wt%=100.00
    h,cal= 3939.6  t(k)=298.15 rho=1.634

### ARC448

    name ARC448  H 3.359766 C 2.052322 N 1.932190 O 2.806300  wt%=100.00
    h,cal= -36867.1  t(k)=298.15 rho=1.537

### ARC452

    name ARC452  H 3.694563 C 2.469813 N 1.041212 O 3.251794  wt%=100.00
    h,cal= -67947.0  t(k)=298.15 rho=1.473

### ARC457

    name ARC457  H 4.080395 C 1.238333 N 1.677693 O 3.593891
    wt%=100.00 h,cal= -80325.0 t(k)=298.15 rho=1.594

### HAN269

    name = HAN N 2.0 H 4.0 O 4.0 wt%= 69.15
    h,cal=-80962. t(k)=298.15 rho,g/cc = 1.685
    name = MEOH C 1.0 H 4.0 O 1.0 wt%= 15.46
    h,cal=-57146. t(k)=298.15 rho,g/cc = 0.791
    name = water H 2.0 O 1.0 wt%= 14.80
    h,cal=-68256. t(k)=298.17 rho,g/cc=1.00
    name = AN H 4.0 N 2.0 O 3.0 wt%= 0.59
    h,cal=-87380. t(k)=298.17 rho,g/cc=1.725

### HAN315

    name = HAN C 0.064 H 4.296 N 2.062 O 4.1 P 0.008 wt%= 44.5
    h.cal=-93980. t(k)=298.15 rho.g/cc=1.685
    name = HEHN C 2.0 H 9.0 N 3.0 O 4.0 wt%= 44.5
    h.cal=-108000. t(k)=298.15 rho.g/cc=1.428
    name = WATER H 2.0 O 1.0 wt%= 11.0
    h.cal=-68000. t(k)=298.15 rho.g/cc=1.0

### HPB24

    name = diss UA 0.6667 H 2.0000 N 1.3333 wt%= 71.46
    h,cal=12094. t(k)=298.15 rho,g/cc = 1.004
    name = water H 2.0 O 1.0  wt%=0.5
    h,cal=-68308.  t(k)=298.15 rho,g/cc = 0.9998
    name = hydra H 4.0 N 2.0 wt%= 4.04
    h,cal=12094. t(k)=298.15 rho,g/cc = 1.004
    name = hydni N 3.000 H 5.000 O 3.000 wt%= 24.00
    h,cal=-50477. t(k)=298.15 rho,g/cc = 1.647

### HYD40

    name = diss UA 0.800 H 1.600 N 1.200 wt%= 99.5
    h,cal=12094. t(k)=298.15 rho,g/cc = 1.004

    name = water H 2.0 O 1.0  wt%=0.5
    h,cal=-68308.  t(k)=298.15 rho,g/cc = 0.9998
    !   THIS IS 40% AMMONIA DISSOCIATION
    omit NH3